import { db } from "@/lib/db"
import { NextResponse } from "next/server";
import fetchUserWithImpersonation from "@/lib/fetch-user-impersonation";

export async function GET(req: Request) {
    try {
        const user = await fetchUserWithImpersonation(req)
        if (!user) {
            return NextResponse.json({ message: 'Unauthorized.', error: null, value: null }, { status: 401 });
        }

        const filters = await db.ttsUsernameFilter.findMany({
            where: {
                userId: user.id
            }
        });

        return NextResponse.json(filters);
    } catch (error) {
        console.log("[TTS/FILTER/USERS]", error);
        return NextResponse.json({ message: 'Something went wrong', error: error, value: null }, { status: 500 })
    }
}

export async function POST(req: Request) {
    try {
        const user = await fetchUserWithImpersonation(req)
        if (!user) {
            return NextResponse.json({ message: 'Unauthorized.', error: null, value: null }, { status: 401 });
        }

        const { username, tag } = await req.json();
        if (!username || username.length < 4 || username.length > 25)
            return NextResponse.json({ message: 'Username does not exist.', error: null, value: null }, { status: 400 })
        if (!tag || !["blacklisted", "priority"].includes(tag))
            return NextResponse.json({ message: 'Tag does not exist.', error: null, value: null }, { status: 400 })

        const filter = await db.ttsUsernameFilter.upsert({
          where: {
            userId_username: {
              userId: user.id as string,
              username: username.toLowerCase()
            }
          },
          update: {
            tag
          },
          create: {
            userId: user.id as string,
            username: username.toLowerCase(),
            tag
          }
        });

        return NextResponse.json(filter);
    } catch (error) {
        return NextResponse.json({ message: 'Something went wrong', error: error, value: null }, { status: 500 })
    }
}

export async function DELETE(req: Request) {
    try {
        const user = await fetchUserWithImpersonation(req)
        if (!user) {
            return NextResponse.json({ message: 'Unauthorized.', error: null, value: null }, { status: 401 });
        }

        const { searchParams } = new URL(req.url)
        const username = searchParams.get('username') as string
        if (!username || username.length < 4 || username.length > 25)
            return NextResponse.json({ message: 'Username does not exist.', error: null, value: null }, { status: 400 })

        const filter = await db.ttsUsernameFilter.delete({
          where: {
            userId_username: {
              userId: user.id as string,
              username
            }
          }
        });

        return NextResponse.json(filter)
    } catch (error) {
        return NextResponse.json({ message: 'Something went wrong', error: error, value: null }, { status: 500 })
    }
}